from setuptools import setup

setup(name='sams_dsnd_probability',
      version=1.2,
      description='Gaussian and Binomial distribution',
      packages=['sams_dsnd_probability'],
      authour='Samuel Ajayi',
      author_email='ajayisamuelofficial@gmail.com',
      zip_safe=False)
